package com.malk.kuaikeli.service.impl;

import com.alibaba.excel.EasyExcel;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.malk.kuaikeli.entity.SupplierMaterial;
import com.malk.kuaikeli.listener.SupplierMaterialDataListener;
import com.malk.kuaikeli.mapper.SupplierMaterialMapper;
import com.malk.kuaikeli.service.SupplierMaterialService;
import com.malk.server.aliwork.YDConf;
import com.malk.server.aliwork.YDParam;
import com.malk.server.common.McR;
import com.malk.service.aliwork.YDClient;
import com.malk.utils.UtilEnv;
import com.malk.utils.UtilMap;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.List;
import java.util.Map;

@Service
@Slf4j
public class SupplierMaterialServiceImpl extends ServiceImpl<SupplierMaterialMapper,SupplierMaterial> implements SupplierMaterialService {

    @Autowired
    private SupplierMaterialMapper supplierMaterialMapper;
    @Autowired
    private YDClient ydClient;

    String _matchFormUuid(String code) {
        Map<String, String> formUuid = UtilMap.empty();
        if (UtilEnv.getActiveProfile().equals(UtilEnv.ENV_PROD)) {
            formUuid.put("SUPPLIERMATERIAL", "FORM-12EB6BCE3C264630824721E7BBABCC03L8U9"); // 供应商原材料档案
            formUuid.put("DOMAIN", "https://dcuvl8.aliwork.com/"); // 宜搭域名
        } else {
            formUuid.put("SUPPLIERMATERIAL", "FORM-0CE39021E25E4F64AD56434209A95F55ZTJD"); // 供应商原材料档案_复制
            formUuid.put("DOMAIN", "https://dcuvl8.aliwork.com/");
        }
        return formUuid.get(code);
    }

    @Override
    public void uploadData(MultipartFile file) {
//        try {
//            EasyExcel.read(file.getInputStream(), SupplierMaterial.class, new SupplierMaterialDataListener(baseMapper)).sheet().doRead();
//        } catch (IOException e) {
//            e.printStackTrace();
//        }
    }

    @Override
    public void sync(String startDateTime) {
        QueryWrapper<SupplierMaterial> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda()
                .ge(SupplierMaterial::getCreateDateTime,startDateTime)
                .or().ge(SupplierMaterial::getUpdateDateTime,startDateTime);
        // 时间判断增量同步
        List<SupplierMaterial> list=baseMapper.selectList(queryWrapper);
        for (SupplierMaterial supplierMaterial:list){
            // 同步到宜搭
            List<Map> yidaList= (List<Map>) ydClient.queryData(YDParam.builder().formUuid(_matchFormUuid("SUPPLIERMATERIAL")).searchCondition(
                    JSONObject.toJSONString(UtilMap.map("textField_llkb7kd2",supplierMaterial.getMaterialId())))
                    .build(),YDConf.FORM_QUERY.retrieve_list).getData();
            YDParam ydParam = YDParam.builder()
                    .formUuid(_matchFormUuid("SUPPLIERMATERIAL"))
                    .useLatestVersion(true)
                    .build();
            Map formData=supplierMaterial.toYidaFormDataMap();
            if(yidaList!=null&&yidaList.size()>0){
                ydParam.setUpdateFormDataJson(JSON.toJSONString(formData));
                ydParam.setFormInstanceId(String.valueOf(yidaList.get(0).get("instanceId")));
                ydClient.operateData(ydParam,YDConf.FORM_OPERATION.update);
            }else{
                ydParam.setFormDataJson(JSON.toJSONString(formData));
                ydClient.operateData(ydParam,YDConf.FORM_OPERATION.create);
            }
        }
    }

    public IPage<SupplierMaterial> getProducts(Page<SupplierMaterial> page, Map<String, Object> params) {
        // 构造查询条件（可选）
        QueryWrapper<SupplierMaterial> queryWrapper = new QueryWrapper<>();
        // ... 根据params设置查询条件 ...

        // 执行分页查询
        return baseMapper.selectPage(page, queryWrapper);
    }

    @Override
    public McR getList(Integer current, Integer size) {
        Page<SupplierMaterial> page=new Page<>(current,size);
        IPage iPage = getProducts(page,null);
        return McR.success(iPage);
    }
}
